import React from 'react';
import {
  Pressable,
  Text,
  ActivityIndicator,
  StyleSheet,
  Dimensions,
  Platform,
} from 'react-native';
import {Colors} from 'global-styles';
const {width} = Dimensions.get('window');

const DefaultButton = props => {
  const {loading, title, outline, isDelete, onPress, disabled} = props;
  const isOutlineColor = outline ? Colors.PRIMARY : Colors.WHITE;
  return (
    <Pressable
      onPress={onPress}
      disabled={disabled}
      android_ripple={{color: ''}}
      style={styles(outline, isDelete, disabled).container}>
      {loading ? (
        <ActivityIndicator size="small" color={isOutlineColor} />
      ) : (
        <Text style={styles(outline, isDelete, disabled).title}>{title}</Text>
      )}
    </Pressable>
  );
};

DefaultButton.defaultProps = {
  loading: false,
  title: '',
  outline: false,
  disabled: false,
};

const styles = (isOutline, isDelete, disabled) =>
  StyleSheet.create({
    container: {
      height: width * 0.12,
      backgroundColor: isOutline ? Colors.WHITE : Colors.PRIMARY,
      borderWidth: 1,
      borderColor: isDelete ? '#d63031' : Colors.PRIMARY,
      borderRadius: width * 0.015,
      alignItems: 'center',
      justifyContent: 'center',
      marginHorizontal: width * 0.01,
      opacity: disabled ? 0.5 : 1,
    },
    title: {
      fontSize: 13,
      color: isDelete ? '#d63031' : isOutline ? Colors.PRIMARY : Colors.WHITE,
      marginTop: Platform.OS === 'android' ? width * 0.008 : 0,
    },
  });

export default DefaultButton;
