import React from 'react';
import {Container} from 'components';
import {View} from 'react-native';
import {DefaultButton, SelectPicture, DefaultTextInput} from 'components';
import useContactDetail from './useContactDetail';

const ContactDetail = ({route, navigation}) => {
  const {data} = route.params;

  const {form, image, onChangeInput, onDelete, onSubmit, pickImageHandler} =
    useContactDetail(data, navigation);

  let isEmpty = false;
  if (
    form.age.trim() === '' ||
    form.firstName.trim() === '' ||
    form.lastName.trim() === '' ||
    (image.foto == null && image.fileUri == null)
  ) {
    isEmpty = true;
  }

  return (
    <Container
      safeAreaStyleProps={{
        marginHorizontal: 15,
        justifyContent: 'space-between',
      }}>
      <View>
        <View style={{alignItems: 'center', marginVertical: 20}}>
          <SelectPicture
            handleOnPress={() => pickImageHandler()}
            title={'Gambar'}
            image={image.fileUri ? image.fileUri : image.foto}
            editable={true}
            created={data}
            isEmpty={!image.fileUri && !image.foto}
          />
        </View>
        <View style={{flexDirection: 'row', marginBottom: 10}}>
          <DefaultTextInput
            onChangeText={val => onChangeInput('firstName', val)}
            label="First name (*)"
            value={form.firstName}
            containerStyle={{
              flex: 1,
              height: form.firstName.trim() === '' ? 80 : 60,
            }}
            isFilled={form.firstName.trim() === ''}
          />
          <DefaultTextInput
            onChangeText={val => onChangeInput('lastName', val)}
            label="Last name (*)"
            value={form.lastName}
            containerStyle={{
              flex: 1,
              height: form.lastName.trim() === '' ? 80 : 60,
            }}
            isFilled={form.lastName.trim() === ''}
          />
        </View>
        <DefaultTextInput
          onChangeText={val => onChangeInput('age', val)}
          label="Age (*)"
          containerStyle={{height: form.age.trim() === '' ? 80 : 60}}
          value={form.age}
          isFilled={form.age.trim() === ''}
          keyboardType="number-pad"
        />
      </View>
      <View style={{marginBottom: 20}}>
        <DefaultButton
          onPress={onSubmit}
          disabled={isEmpty}
          title={data ? 'UPDATE' : 'SIMPAN'}
        />
        {data && (
          <>
            <View style={{margin: 10}} />
            <DefaultButton outline isDelete onPress={onDelete} title="HAPUS" />
          </>
        )}
      </View>
    </Container>
  );
};

export default ContactDetail;
