import {useState} from 'react';
import {launchImageLibrary} from 'react-native-image-picker';
import {updateContact, deleteContact, createContact} from 'services';
import {Toast} from 'react-native-toast-message/lib/src/Toast';

const useContactDetail = (data, navigation) => {
  const [form, setForm] = useState({
    firstName: data ? data.firstName : '',
    lastName: data ? data.lastName : '',
    age: data ? data.age.toString() : '',
  });
  const [image, setImage] = useState({
    fileUri: null,
    file: null,
    foto: data ? data.photo : null,
  });

  const pickImageHandler = async () => {
    const options = {
      maxWidth: 500,
      maxHeight: 500,
      noData: true,
      mediaType: 'photo',
      includeBase64: true,
    };
    const result = await launchImageLibrary(options);
    if (result) {
      setImage({
        fileUri: result.assets[0].uri,
        file: result.assets[0].base64,
        foto: result.assets[0].fileName,
      });
    }
  };

  const onChangeInput = (obj, val) => {
    setForm({
      ...form,
      [obj]: val,
    });
  };

  const onSubmit = async () => {
    const payload = {
      firstName: form.firstName,
      lastName: form.lastName,
      age: Number(form.age),
      photo: image.file ? `data:image/png;base64,${image.file}` : image.foto,
    };
    if (data) {
      const res = await updateContact(data.id, payload);
      if (res.error) {
        Toast.show({
          type: 'error',
          text1: 'Gagal',
          text2: 'Terjadi kesalahan saat menghapus contact',
          visibilityTime: 1500,
        });
        return;
      }
      Toast.show({
        type: 'success',
        text1: 'Success',
        text2: 'Contact  berhasil diupdate',
        visibilityTime: 1500,
      });
    } else {
      const res = await createContact(payload);
      if (res.error) {
        Toast.show({
          type: 'error',
          text1: 'Gagal',
          text2: 'Terjadi kesalahan saat menghapus contact',
          visibilityTime: 1500,
        });
        return;
      }
      Toast.show({
        type: 'success',
        text1: 'Success',
        text2: 'Contact baru berhasil tersimpan',
        visibilityTime: 1500,
      });
    }
    setTimeout(() => {
      navigation.goBack();
    }, 1500);
  };

  const onDelete = () => {
    deleteContact(data.id)
      .then(res => {
        if (res.error) {
          Toast.show({
            type: 'error',
            text1: 'Gagal',
            text2: 'Terjadi kesalahan saat menghapus contact',
            visibilityTime: 1500,
          });
          return;
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  return {
    onDelete,
    onChangeInput,
    onSubmit,
    pickImageHandler,
    form,
    setForm,
    image,
    setImage,
  };
};

export default useContactDetail;
