import React, {useState} from 'react';
import {
  View,
  Text,
  FlatList,
  Image,
  Pressable,
  RefreshControl,
} from 'react-native';
import {useSelector, useDispatch} from 'react-redux';
import {getContact} from 'services/contact.services';
import {useFocusEffect} from '@react-navigation/native';
import {saveContacts} from 'actions';
import {Container, FabButton} from 'components';

const Home = ({navigation}) => {
  const [isListRefresh, setIsListRefresh] = useState(false);
  const dispatch = useDispatch();
  const contacts = useSelector(state => state.contacts.data);

  const getAllContacts = async () => {
    getContact()
      .then(res => {
        dispatch(saveContacts([...res.data]));
      })
      .catch(err => {
        alert('Something wrong', err);
      });
    setIsListRefresh(false);
  };

  const onListRefresh = () => {
    setIsListRefresh(true);
    getAllContacts();
  };

  useFocusEffect(() => {
    getAllContacts();
  });

  return (
    <Container>
      <FlatList
        data={contacts}
        keyExtractor={(_, index) => index.toString()}
        contentContainerStyle={{paddingBottom: 20}}
        refreshControl={
          <RefreshControl
            refreshing={isListRefresh}
            onRefresh={() => onListRefresh()}
          />
        }
        renderItem={({item, index}) => (
          <Pressable
            android_ripple={{color: '#3c40c6'}}
            onPress={() => navigation.navigate('Contact Detail', {data: item})}>
            <View
              style={{
                flexDirection: 'row',
                borderBottomWidth: 0.5,
                padding: 5,
              }}>
              <Image
                style={{width: 64, height: 64, borderRadius: 7}}
                source={{uri: item.photo}}
              />
              <View style={{marginLeft: 10}}>
                <Text style={{color: 'black'}}>
                  Name: {item.firstName} {item.lastName}
                </Text>
                <Text style={{color: 'black'}}>Age: {item.age}</Text>
              </View>
            </View>
          </Pressable>
        )}
      />
      <FabButton
        onPress={() => navigation.navigate('Contact Detail', {data: null})}
      />
    </Container>
  );
};

export default Home;
